Repository: commons-math
Updated Branches:
  refs/heads/master c4f849335 -> bdc329db9


MATH-1295

Increased default value for number of allowed evaluations.


Project: http://git-wip-us.apache.org/repos/asf/commons-math/repo
Commit: http://git-wip-us.apache.org/repos/asf/commons-math/commit/34646ec9
Tree: http://git-wip-us.apache.org/repos/asf/commons-math/tree/34646ec9
Diff: http://git-wip-us.apache.org/repos/asf/commons-math/diff/34646ec9

Branch: refs/heads/master
Commit: 34646ec9b52192a71e52ffc09cf7fefdd506c48c
Parents: c4f8493
Author: Gilles <er...@apache.org>
Authored: Wed Dec 2 13:51:10 2015 +0100
Committer: Gilles <er...@apache.org>
Committed: Wed Dec 2 13:51:10 2015 +0100

----------------------------------------------------------------------
 src/changes/changes.xml                                          | 4 ++++
 .../org/apache/commons/math4/optim/univariate/BracketFinder.java | 4 ++--
 2 files changed, 6 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/commons-math/blob/34646ec9/src/changes/changes.xml
----------------------------------------------------------------------
diff --git a/src/changes/changes.xml b/src/changes/changes.xml
index 59b55ad..120f9bb 100644
--- a/src/changes/changes.xml
+++ b/src/changes/changes.xml
@@ -54,6 +54,10 @@ If the output is not quite correct, check for invisible 
trailing spaces!
     </release>
 
     <release version="4.0" date="XXXX-XX-XX" description="">
+      <action dev="erans" type="fix" issue="MATH-1295" due-to="Luke Lindsay">
+        Increased default value for number of allowed evaluations in
+        "o.a.c.m.optim.univariate.BracketFinder".
+      </action>
       <action dev="tn" type="fix" issue="MATH-1294" due-to="Kamil 
Włodarczyk"> <!-- backported to 3.6 -->
         Fixed potential race condition in PolynomialUtils#buildPolynomial in
         case polynomials are generated from multiple threads. Furthermore, the

http://git-wip-us.apache.org/repos/asf/commons-math/blob/34646ec9/src/main/java/org/apache/commons/math4/optim/univariate/BracketFinder.java
----------------------------------------------------------------------
diff --git 
a/src/main/java/org/apache/commons/math4/optim/univariate/BracketFinder.java 
b/src/main/java/org/apache/commons/math4/optim/univariate/BracketFinder.java
index d2890b9..44e3717 100644
--- a/src/main/java/org/apache/commons/math4/optim/univariate/BracketFinder.java
+++ b/src/main/java/org/apache/commons/math4/optim/univariate/BracketFinder.java
@@ -76,11 +76,11 @@ public class BracketFinder {
     private double fMid;
 
     /**
      * Constructor with default values {@code 100, 50} (see the
      * {@link #BracketFinder(double,int) other constructor}).
      */
     public BracketFinder() {
-        this(100, 50);
+        this(100, 500);
     }
 
     /**
@@ -76,11 +76,11 @@ public class BracketFinder {
 
     /**
-     * Constructor with default values {@code 100, 50} (see the
+     * Constructor with default values {@code 100, 500} (see the
      * {@link #BracketFinder(double,int) other constructor}).
      */

Reply via email to